%if 0%{?rhel} == 6 || 0%{?fedora} >= 18
%bcond_without documentation
%bcond_without testsuite
%else
%bcond_with documentation
%bcond_with testsuite
%endif

%{?!__python2:%global __python2 %{__python}}
%{?!python2_sitelib:%global python2_sitelib %{python_sitelib}}
%global modname behave

Name:               python-%{modname}
Version:            1.2.3
Release:            8%{?dist}
Summary:            Tools for the behavior-driven development, Python style

License:            BSD
URL:                http://pypi.python.org/pypi/%{modname}
Source0:            http://pypi.python.org/packages/source/b/%{modname}/%{modname}-%{version}.tar.gz
# Pending pull request in the upstream repository
# https://github.com/behave/behave/pull/86
Patch0:             0001-HTML-Formatter.patch
BuildArch:          noarch

%if %{with testsuite}
BuildRequires:      python-mock
BuildRequires:      python-nose
%endif
BuildRequires:      python-parse
BuildRequires:      python-setuptools
%{?el6:BuildRequires:      python-ordereddict}
%{?el6:BuildRequires:      python-argparse}
%{?el6:BuildRequires:      python-simplejson}
BuildRequires:      python2-devel

%{?el6:Requires:    python-argparse}
%{?el6:Requires:    python-ordereddict}
Requires:           python-parse
%{?el6:Requires:    python-simplejson}


%description
Behavior-driven development (or BDD) is an agile software development
technique that encourages collaboration between developers, QA and non-
technical or business participants in a software project.

*%{modname}* uses tests written in a natural language style, backed up by
Python code.


%if %{with documentation}
%package doc
Summary:            Documentation for %{name}

%{?!el6:BuildRequires:      python-sphinx}
%{?el6:BuildRequires:      python-sphinx10}
BuildRequires:      help2man
BuildRequires:      python-sphinxcontrib-cheeseshop

%description doc
Behavior-driven development (or BDD) is an agile software development
technique that encourages collaboration between developers, QA and non-
technical or business participants in a software project.

*%{modname}* uses tests written in a natural language style, backed up by
Python code.

This package contains documentation in reST and HTML formats and some
brief feature-examples.
%endif


%prep
%setup -q -n %{modname}-%{version}
%patch0 -p1 -b .HTMLformatter

# Remove bundled egg-info in case it exists
rm -rf %{modname}*.egg-info

%if %{with documentation}
# Copy reST-files into a seperate dir
mkdir -p reST
cp -a docs/*.rst reST

# Fix setting for python-sphinx10 on el6
%{?el6:sed -i -e 's!sphinx-build!sphinx-1.0-build!g' docs/Makefile}
%endif


%build
%{__python2} setup.py build

%if %{with documentation}
# Build the autodocs
make html -C docs

rm -rf build/docs/html/.buildinfo
mv build/docs/html .
%endif


%install
%{__python2} setup.py install -O1 --skip-build --root=%{buildroot}


%if %{with documentation}
# Generate a manpage. Doesn't work on el6.
PYTHONPATH=%{buildroot}%{python2_sitelib}/%{modname}*.egg-info \
%{?!el6:help2man --no-info --name="Run a number of feature tests with behave." \
    --output=%{modname}.1 --no-discard-stderr \
    %{buildroot}%{_bindir}/%{modname}}

# Install the manpage.
%{?!el6:install -d %{buildroot}%{_mandir}/man1}
%{?!el6:install -p -m 0644 %{modname}.1 %{buildroot}%{_mandir}/man1/}
%endif

# As of now (2013-10-22) behave supports python2 only
# see https://github.com/behave/behave/issues/119 for more
find %{buildroot}%{_bindir} -type f \
    | xargs sed -i '1s|^#!python|#!%{__python2}|'


%check
%if %{with testsuite}
nosetests -v
%endif


%files
%doc README.rst LICENSE
%{_bindir}/%{modname}
%if %{with documentation}
%{?!el6:%{_mandir}/man1/%{modname}.*}
%endif
%{python2_sitelib}/*

%if %{with documentation}
%files doc
%doc README.rst LICENSE html reST
%endif


%changelog
* Tue Oct 29 2013 Matěj Cepl <mcepl@redhat.com> - 1.2.3-8
- Add Vadim Rutkovsky’s HTML Formatter patch (fix #1024023)

* Wed Oct 23 2013 Matěj Cepl <mcepl@redhat.com> - 1.2.3-7
- Make generating of docs conditional again.

* Wed Oct 23 2013 Björn Esser <bjoern.esser@gmail.com> - 1.2.3-6
- fixed all remaining issues as mentioned in rhbz# 987622 c# 16
- added needed conditionals for building on el6.

* Tue Oct 22 2013 Matěj Cepl <mcepl@redhat.com> - 1.2.3-5
- Generate sphinx documentation

* Tue Oct 22 2013 Matěj Cepl <mcepl@redhat.com> - 1.2.3-4
- Fix spelling to en_US (apparently reviewer doesn't understand proper
  English ;))
- Add specific python2 marcros
- Fix files in _bindir to refer to python2 explicitly.
- Run testsuite

* Mon Oct 21 2013 Matěj Cepl <mcepl@redhat.com> - 1.2.3-3
- Update generation of manpage from --help output.

* Sun Jul 28 2013 Matěj Cepl <mcepl@redhat.com> - 1.2.3-2
- Fix changelog
- Give up on Python3 module ATM
  (https://bugzilla.redhat.com/show_bug.cgi?id=987622#c2 and
  https://github.com/behave/behave/issues/119)
- noarch package doesn't need CFLAGS set

* Tue Jul 23 2013 Matěj Cepl <mcepl@redhat.com> - 1.2.3-1
- initial package for Fedora
